package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.InitialSwitchFanInfo;

import java.util.List;
import java.util.Map;

/**
 * 风扇信息Mapper接口
 * 
 * @author gyt
 * @date 2025-09-22
 */
public interface InitialSwitchFanInfoMapper 
{
    /**
     * 查询风扇信息
     * 
     * @param id 风扇信息主键
     * @return 风扇信息
     */
    public InitialSwitchFanInfo selectInitialSwitchFanInfoById(Long id);

    /**
     * 查询风扇信息列表
     * 
     * @param initialSwitchFanInfo 风扇信息
     * @return 风扇信息集合
     */
    public List<InitialSwitchFanInfo> selectInitialSwitchFanInfoList(InitialSwitchFanInfo initialSwitchFanInfo);

    /**
     * 新增风扇信息
     * 
     * @param initialSwitchFanInfo 风扇信息
     * @return 结果
     */
    public int insertInitialSwitchFanInfo(InitialSwitchFanInfo initialSwitchFanInfo);

    /**
     * 修改风扇信息
     * 
     * @param initialSwitchFanInfo 风扇信息
     * @return 结果
     */
    public int updateInitialSwitchFanInfo(InitialSwitchFanInfo initialSwitchFanInfo);

    /**
     * 删除风扇信息
     * 
     * @param id 风扇信息主键
     * @return 结果
     */
    public int deleteInitialSwitchFanInfoById(Long id);

    /**
     * 批量删除风扇信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialSwitchFanInfoByIds(Long[] ids);

    /**
     * 批量新增风扇信息
     * @param list
     * @return
     */
    public int insertBatchInitialSwitchFanInfo(List<InitialSwitchFanInfo> list);

    /**
     * 获取指定交换机的风扇名称
     * @param initialSwitchFanInfo
     * @return
     */
    List<Map> getAllFanName(InitialSwitchFanInfo initialSwitchFanInfo);

    /**
     * 获取风扇基础信息
     * @param initialSwitchFanInfo
     * @return
     */
    List<InitialSwitchFanInfo> getFanMsg(InitialSwitchFanInfo initialSwitchFanInfo);
}
